@@ -37,7 +37,7 @@ async def test_connect_success_and_reconnect_with_gpio(caplog, pygw, pygw_proto)
         pygw_proto,
         "init_and_wait_for_activity",
     ) as init_and_wait, patch(
-        "serial_asyncio.create_serial_connection",
+        "serial_asyncio_fast.create_serial_connection",
         return_value=(pygw_proto.transport, pygw_proto),
     ), caplog.at_level(
         logging.DEBUG
@@ -75,7 +75,7 @@ async def test_connect_skip_init(caplog, pygw, pygw_proto):
         pygw_proto,
         "init_and_wait_for_activity",
     ) as init_and_wait, patch(
-        "serial_asyncio.create_serial_connection",
+        "serial_asyncio_fast.create_serial_connection",
         return_value=(pygw_proto.transport, pygw_proto),
     ), caplog.at_level(
         logging.DEBUG
@@ -106,7 +106,7 @@ async def test_connect_serialexception(caplog, pygw):
     loop = asyncio.get_running_loop()
 
     with patch(
-        "serial_asyncio.create_serial_connection",
+        "serial_asyncio_fast.create_serial_connection",
         side_effect=serial.serialutil.SerialException,
     ) as create_serial_connection, patch.object(
         pygw.connection,
@@ -137,7 +137,7 @@ async def test_connect_serialexception(caplog, pygw):
 async def test_connect_cancel(pygw):
     """Test pyotgw.connect() with CancelledError"""
     with patch(
-        "serial_asyncio.create_serial_connection",
+        "serial_asyncio_fast.create_serial_connection",
         side_effect=asyncio.CancelledError,
     ) as create_serial_connection:
         status = await pygw.connect("loop://")
@@ -161,7 +161,7 @@ async def test_connect_timeouterror(caplog, pygw, pygw_proto):
         "_get_retry_timeout",
         return_value=0,
     ) as loops_done, patch(
-        "serial_asyncio.create_serial_connection",
+        "serial_asyncio_fast.create_serial_connection",
         return_value=(pygw_proto.transport, pygw_proto),
     ), caplog.at_level(
         logging.DEBUG
@@ -191,7 +191,7 @@ async def test_disconnect_while_connecting(pygw):
     loop = asyncio.get_running_loop()
 
     with patch(
-        "serial_asyncio.create_serial_connection",
+        "serial_asyncio_fast.create_serial_connection",
         side_effect=serial.SerialException,
     ):
         task = loop.create_task(pygw.connect("loop://"))
@@ -851,6 +851,24 @@ async def test_set_ventilation(pygw):
     update_status.assert_called_once_with(v.BOILER, {v.DATA_COOLING_CONTROL: 75})
 
 
+@pytest.mark.asyncio
+async def test_send_transparent_command(pygw):
+    """Test pyotgw.send_transparent_command()"""
+    with patch.object(
+        pygw,
+        "_wait_for_cmd",
+        side_effect=["CD"],
+    ) as wait_for_cmd:
+        assert await pygw.send_transparent_command("AB", "CD") == "CD"
+
+    assert wait_for_cmd.call_count == 1
+    wait_for_cmd.assert_has_awaits(
+        [
+            call("AB", "CD", v.OTGW_DEFAULT_TIMEOUT),
+        ],
+    )
+
+
 def test_subscribe_and_unsubscribe(pygw):
     """Test pyotgw.subscribe() and pyotgw.unsubscribe()"""
 
